#!/usr/bin/python

class GrabzItException(Exception):

        SUCCESS = 0
        PARAMETER_NO_URL = 100
        PARAMETER_INVALID_URL = 101
        PARAMETER_NON_EXISTANT_URL = 102
        PARAMETER_MISSING_APPLICATION_KEY = 103
        PARAMETER_UNRECOGNISED_APPLICATION_KEY = 104
        PARAMETER_MISSING_SIGNATURE = 105
        PARAMETER_INVALID_SIGNATURE = 106
        PARAMETER_INVALID_FORMAT = 107
        PARAMETER_INVALID_COUNTRY_CODE = 108
        PARAMETER_DUPLICATE_IDENTIFIER = 109
        PARAMETER_MATCHING_RECORD_NOT_FOUND = 110
        PARAMETER_INVALID_CALLBACK_URL = 111
        PARAMETER_NON_EXISTANT_CALLBACK_URL = 112
        PARAMETER_IMAGE_WIDTH_TOO_LARGE = 113
        PARAMETER_IMAGE_HEIGHT_TOO_LARGE = 114
        PARAMETER_BROWSER_WIDTH_TOO_LARGE = 115
        PARAMETER_BROWSER_HEIGHT_TOO_LARGE = 116
        PARAMETER_DELAY_TOO_LARGE = 117
        PARAMETER_INVALID_BACKGROUND = 118
        PARAMETER_INVALID_INCLUDE_LINKS = 119
        PARAMETER_INVALID_INCLUDE_OUTLINE = 120
        PARAMETER_INVALID_PAGE_SIZE = 121
        PARAMETER_INVALID_PAGE_ORIENTATION = 122
        PARAMETER_VERTICAL_MARGIN_TOO_LARGE = 123
        PARAMETER_HORIZONTAL_MARGIN_TOO_LARGE = 124
        PARAMETER_INVALID_COVER_URL = 125
        PARAMETER_NON_EXISTANT_COVER_URL = 126
        PARAMETER_MISSING_COOKIE_NAME = 127
        PARAMETER_MISSING_COOKIE_DOMAIN = 128
        PARAMETER_INVALID_COOKIE_NAME = 129
        PARAMETER_INVALID_COOKIE_DOMAIN = 130
        PARAMETER_INVALID_COOKIE_DELETE = 131
        PARAMETER_INVALID_COOKIE_HTTP = 132
        PARAMETER_INVALID_COOKIE_EXPIRY = 133
        PARAMETER_INVALID_CACHE_VALUE = 134
        PARAMETER_INVALID_DOWNLOAD_VALUE = 135
        PARAMETER_INVALID_SUPPRESS_VALUE = 136
        PARAMETER_MISSING_WATERMARK_IDENTIFIER = 137
        PARAMETER_INVALID_WATERMARK_IDENTIFIER = 138
        PARAMETER_INVALID_WATERMARK_XPOS = 139
        PARAMETER_INVALID_WATERMARK_YPOS = 140
        PARAMETER_MISSING_WATERMARK_FORMAT = 141
        PARAMETER_WATERMARK_TOO_LARGE = 142
        PARAMETER_MISSING_PARAMETERS = 143
        PARAMETER_QUALITY_TOO_LARGE = 144
        PARAMETER_QUALITY_TOO_SMALL = 145
        PARAMETER_REPEAT_TOO_SMALL = 149
        PARAMETER_INVALID_REVERSE = 150
        PARAMETER_FPS_TOO_LARGE = 151
        PARAMETER_FPS_TOO_SMALL = 152
        PARAMETER_SPEED_TOO_FAST = 153
        PARAMETER_SPEED_TOO_SLOW = 154
        PARAMETER_INVALID_ANIMATION_COMBINATION = 155
        PARAMETER_START_TOO_SMALL = 156
        PARAMETER_DURATION_TOO_SMALL = 157
        PARAMETER_NO_HTML = 163
        PARAMETER_INVALID_TARGET_VALUE = 165
        PARAMETER_INVALID_HIDE_VALUE = 166     
        PARAMETER_INVALID_INCLUDE_IMAGES = 167       
        PARAMETER_INVALID_EXPORT_URL = 168
        PARAMETER_INVALID_WAIT_FOR_VALUE = 169
        PARAMETER_INVALID_TRANSPARENT_VALUE = 170
        PARAMETER_INVALID_ENCRYPTION_KEY = 171
        PARAMETER_INVALID_NO_ADS = 172
        PARAMETER_INVALID_PROXY = 173
        PARAMETER_INVALID_NO_NOTIFY = 174
        PARAMETER_INVALID_HD = 176
        PARAMETER_INVALID_MEDIA_TYPE = 177
        PARAMETER_INVALID_PASSWORD = 178
        PARAMETER_INVALID_MERGE = 179
        PARAMETER_INVALID_CLICK_VALUE = 180
        NETWORK_SERVER_OFFLINE = 200
        NETWORK_GENERAL_ERROR = 201
        NETWORK_DDOS_ATTACK = 202
        RENDERING_ERROR = 300
        RENDERING_MISSING_SCREENSHOT = 301
        GENERIC_ERROR = 400
        UPGRADE_REQUIRED = 500
        FILE_SAVE_ERROR = 600
        FILE_NON_EXISTANT_PATH = 601

        def __init__(self, message, code):
                Exception.__init__(self, message)
                self.Code = code


#!/usr/bin/python

from GrabzIt import GrabzItBaseOptions

class GrabzItTableOptions(GrabzItBaseOptions.GrabzItBaseOptions):
        """ Available options when creating a Table capture

            Attributes:

            tableNumberToInclude    the index of the table to be converted, were all tables in a web page are ordered from the top of the web page to bottom
            format                  the format the table should be in: csv, xlsx or json
            includeHeaderNames      set to true to include header names into the table
            includeAllTables        set to true to extract every table on the web page into a separate spreadsheet sheet. Only available with the XLSX and JSON formats
            targetElement           the id of the only HTML element in the web page that should be used to extract tables from
            requestAs               which user agent type should be used: Standard Browser = 0, Mobile Browser = 1, Search Engine = 2 and Fallback Browser = 3
            address                 the URL to execute the HTML code in            
        """
        
        def __init__(self):
                GrabzItBaseOptions.GrabzItBaseOptions.__init__(self)
                self.tableNumberToInclude = 1
                self.format = 'csv'
                self.includeHeaderNames = True
                self.includeAllTables = False
                self.targetElement = ''
                self.requestAs = 0
                self.address = ''                
                
        #
        # Define a HTTP Post parameter and optionally value, this method can be called multiple times to add multiple parameters. Using this method will force 
        # GrabzIt to perform a HTTP post.
        #
        # name - The name of the HTTP Post parameter
        # value - The value of the HTTP Post parameter
        #               
        def AddPostParameter(self, name, value):
                self.post = self._appendParameter(self.post, name, value)
                
        def _getParameters(self, applicationKey, sig, callBackURL, dataName, dataValue):
                params = self._createParameters(applicationKey, sig, callBackURL, dataName, dataValue)
                params["includeAllTables"] = int(self.includeAllTables)
                params["includeHeaderNames"] = int(self.includeHeaderNames)
                params["format"] = str(self.format) 
                params["tableToInclude"] = int(self.tableNumberToInclude) 
                params["target"] = str(self.targetElement) 
                params["requestmobileversion"] = str(self.requestAs)            
                params["post"] = str(self.post)             
                params["address"] = str(self.address)
                
                return params

        def _getSignatureString(self, applicationSecret, callBackURL, url = ''):
                urlParam = '';
                if (url != None and url != ''):
                        urlParam = str(url)+"|"

                callBackURLParam = '';
                if (callBackURL != None and callBackURL != ''):
                        callBackURLParam = str(callBackURL)

                return applicationSecret +"|"+ urlParam + callBackURLParam + \
                "|"+str(self.customId)+"|"+str(int(self.tableNumberToInclude))+"|"+str(int(self.includeAllTables))+"|"+str(int(self.includeHeaderNames))+"|"+str(self.targetElement)+ \
                "|"+str(self.format)+"|"+str(int(self.requestAs))+"|"+str(self.country)+"|"+str(self.exportURL)+"|"+str(self.encryptionKey)+"|"+str(self.post)+"|"+str(self.proxy)+"|"+str(self.address)
                


#!/usr/bin/python

import os

try:
	from urllib.parse import urlencode
	from urllib.parse import unquote	
	from urllib.request import urlopen
	from urllib.parse import urlparse
	from urllib.parse import quote
	import http.client as httpClient
except ImportError:
	from urllib import urlopen
	from urlparse import urlparse
	from urllib import urlencode
	from urllib import unquote
	from urllib import quote
	import httplib as httpClient

import hashlib	
import mimetypes
import io
import base64
from xml.dom import minidom
from time import sleep
from GrabzIt import GrabzItCookie
from GrabzIt import ScreenShotStatus
from GrabzIt import GrabzItWaterMark
from GrabzIt import GrabzItException
from GrabzIt import Request
from GrabzIt import GrabzItBaseOptions
from GrabzIt import GrabzItAnimationOptions
from GrabzIt import GrabzItImageOptions
from GrabzIt import GrabzItPDFOptions
from GrabzIt import GrabzItDOCXOptions
from GrabzIt import GrabzItTableOptions
from GrabzIt import GrabzItHTMLOptions
from GrabzIt import GrabzItVideoOptions
from GrabzIt import AES
from GrabzIt import BlockFeeder

class GrabzItClient:

		WebServiceHostName = "api.grabz.it"
		WebServicesBaseURL = "/services/"
		TakePicture = "takepicture"
		TakeVideo = "takevideo"
		TakePDF = "takepdf"
		TakeDOCX = "takedocx"
		TakeTable = "taketable"
		TakeHTML = "takehtml"
		TrueString = "True"

		def __init__(self, applicationKey, applicationSecret):
				self.applicationKey = applicationKey
				self.applicationSecret = applicationSecret
				self.request = None
				self.protocol = "http"
				self.proxy = None
			  
		#
		# This method enables a local proxy server to be used for all requests
		#
		# proxyUrl - the URL, which can include a port if required, of the proxy. Providing a null will remove any previously set proxy
		#
		def SetLocalProxy(self, proxyUrl):
			self.proxy = proxyUrl
			  
		#
		# This method specifies the URL of the online video that should be converted into a animated GIF
		#
		# url - The URL to convert into a animated GIF
		# options - A instance of the GrabzItAnimationOptions class that defines any special options to use when creating the animated GIF
		#
		def URLToAnimation(self, url, options = None):
				if (options == None):
						options = GrabzItAnimationOptions.GrabzItAnimationOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + "takeanimation", False, options, url)
			
		#
		# This method specifies the URL that should be converted into a image screenshot.
		#
		# url - The URL to capture as a screenshot
		# options - A instance of the GrabzItImageOptions class that defines any special options to use when creating the screenshot
		#
		def URLToImage(self, url, options = None):
				if (options == None):
						options = GrabzItImageOptions.GrabzItImageOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakePicture, False, options, url)

		#
		# This method specifies the HTML that should be converted into a image.
		#
		# html - The HTML to convert into a image
		# options - A instance of the GrabzItImageOptions class that defines any special options to use when creating the image
		#				 
		def HTMLToImage(self, html, options = None):
				if (options == None):
						options = GrabzItImageOptions.GrabzItImageOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakePicture, True, options, html)

		#
		# This method specifies a HTML file that should be converted into a image.
		#
		# path - The file path of a HTML file to convert into a image
		# options - A instance of the GrabzItImageOptions class that defines any special options to use when creating the image
		#				 
		def FileToImage(self, path, options = None):
				self.HTMLToImage(self.ReadFile(path), options)

		#
		# This method specifies the URL that should be converted into a video.
		#
		# url - The URL to capture as a video
		# options - A instance of the GrabzItVideoOptions class that defines any special options to use when creating the video
		#
		def URLToVideo(self, url, options = None):
				if (options == None):
						options = GrabzItVideoOptions.GrabzItVideoOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakeVideo, False, options, url)

		#
		# This method specifies the HTML that should be converted into a video.
		#
		# html - The HTML to convert into a video
		# options - A instance of the GrabzItVideoOptions class that defines any special options to use when creating the video
		#				 
		def HTMLToVideo(self, html, options = None):
				if (options == None):
						options = GrabzItVideoOptions.GrabzItVideoOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakeVideo, True, options, html)

		#
		# This method specifies a HTML file that should be converted into a video.
		#
		# path - The file path of a HTML file to convert into a video
		# options - A instance of the GrabzItVideoOptions class that defines any special options to use when creating the video
		#				 
		def FileToVideo(self, path, options = None):
				self.HTMLToVideo(self.ReadFile(path), options)

		#
		# This method specifies the URL that should be converted into rendered HTML.
		#
		# url - The URL to capture as rendered HTML
		# options - A instance of the GrabzItHTMLOptions class that defines any special options to use when creating the rendered HTML
		#
		def URLToRenderedHTML(self, url, options = None):
				if (options == None):
						options = GrabzItHTMLOptions.GrabzItHTMLOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakeHTML, False, options, url)

		#
		# This method specifies the HTML that should be converted into rendered HTML.
		#
		# html - The HTML to convert into rendered HTML
		# options - A instance of the GrabzItImageOptions class that defines any special options to use when creating the rendered HTML
		#				 
		def HTMLToRenderedHTML(self, html, options = None):
				if (options == None):
						options = GrabzItHTMLOptions.GrabzItHTMLOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakeHTML, True, options, html)

		#
		# This method specifies a HTML file that should be converted into rendered HTML.
		#
		# path - The file path of a HTML file to convert into rendered HTML
		# options - A instance of the GrabzItImageOptions class that defines any special options to use when creating the rendered HTML
		#				 
		def FileToRenderedHTML(self, path, options = None):
				self.HTMLToRenderedHTML(self.ReadFile(path), options)#

		#
		# This method specifies the URL that the HTML tables should be extracted from.
		#
		# url - The URL to extract HTML tables from.
		# options - A instance of the GrabzItTableOptions class that defines any special options to use when converting the HTML table
		#
		def URLToTable(self, url, options = None):
				if (options == None):
						options = GrabzItTableOptions.GrabzItTableOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakeTable, False, options, url)

		#
		# This method specifies the HTML that the HTML tables should be extracted from.
		#
		# html - The HTML to extract HTML tables from
		# options - A instance of the GrabzItTableOptions class that defines any special options to use when converting the HTML table	
		#
		def HTMLToTable(self, html, options = None):
				if (options == None):
						options = GrabzItTableOptions.GrabzItTableOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakeTable, True, options, html)				

		#
		# This method specifies a HTML file that the HTML tables should be extracted from.
		#
		# path - The file path of a HTML file to extract HTML tables from.
		# options - A instance of the GrabzItTableOptions class that defines any special options to use when converting the HTML table 
		#
		def FileToTable(self, path, options = None):
				self.HTMLToTable(self.ReadFile(path), options) 
				
		#
		# This method specifies the URL that should be converted into a PDF.
		#
		# url - The URL to capture as a PDF
		# options - A instance of the GrabzItPDFOptions class that defines any special options to use when creating the PDF
		#
		def URLToPDF(self, url, options = None):
				if (options == None):
						options = GrabzItPDFOptions.GrabzItPDFOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakePDF, False, options, url)

		#
		# This method specifies the HTML that should be converted into a PDF.
		#
		# html - The HTML to convert into a PDF
		# options - A instance of the GrabzItPDFOptions class that defines any special options to use when creating the PDF.
		#
		def HTMLToPDF(self, html, options = None):
				if (options == None):
						options = GrabzItPDFOptions.GrabzItPDFOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakePDF, True, options, html)				  

		#
		# This method specifies a HTML file that should be converted into a PDF.
		#
		# path - The file path of a HTML file to convert into a PDF
		# options - A instance of the GrabzItPDFOptions class that defines any special options to use when creating the PDF 
		#
		def FileToPDF(self, path, options = None):
				self.HTMLToPDF(self.ReadFile(path), options)

		#
		# This method specifies the URL that should be converted into a DOCX.
		#
		# url - The URL to capture as a DOCX
		# options - A instance of the GrabzItDOCXOptions class that defines any special options to use when creating the DOCX
		#
		def URLToDOCX(self, url, options = None):
				if (options == None):
						options = GrabzItDOCXOptions.GrabzItDOCXOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakeDOCX, False, options, url)

		#
		# This method specifies the HTML that should be converted into a PDF.
		#
		# html - The HTML to convert into a DOCX
		# options - A instance of the GrabzItDOCXOptions class that defines any special options to use when creating the DOCX.
		#
		def HTMLToDOCX(self, html, options = None):
				if (options == None):
						options = GrabzItDOCXOptions.GrabzItDOCXOptions()
				
				self.request = Request.Request(self.WebServicesBaseURL + self.TakeDOCX, True, options, html)			   

		#
		# This method specifies a HTML file that should be converted into a DOCX.
		#
		# path - The file path of a HTML file to convert into a DOCX
		# options - A instance of the GrabzItDOCXOptions class that defines any special options to use when creating the DOCX 
		#
		def FileToDOCX(self, path, options = None):
				self.HTMLToDOCX(self.ReadFile(path), options)
				
		#
		# This function attempts to Save the result asynchronously and returns a unique identifier, which can be used to get the screenshot with the #GetResult method.
		#
		# This is the recommended method of saving a file.
		#
		def Save(self, callBackURL = ''):
				if (self.request == None ):
						raise GrabzItException.GrabzItException("No parameters have been set.", GrabzItException.GrabzItException.PARAMETER_MISSING_PARAMETERS)
				
				sig = self.CreateSignature(self.request.options._getSignatureString(self.applicationSecret, callBackURL, self.request._targetUrl()))							   

				obj = self._take(sig, callBackURL)
				
				if (obj == None or obj == ""):
					obj = self._take(sig, callBackURL)

				if (obj == None or obj == ""):
					raise GrabzItException.GrabzItException('An unknown network error occurred, please try calling this method again.', GrabzItException.GrabzItException.NETWORK_GENERAL_ERROR)
				
				return self.GetResultObject(obj, "ID");

		def _take(self, sig, callBackURL):
				if (self.request.isPost == False):				
						return self.HTTPGet(self.request.url + '?' + urlencode(self.request.options._getParameters(self.applicationKey, sig, callBackURL, 'url', self.request.data)))
				else:
						return self.HTTPPost(self.request.url, self.request.options._getParameters(self.applicationKey, sig, callBackURL, 'html', quote(self.request.data)))

		#
		# Calls the GrabzIt web service to take the screenshot and saves it to the target path provided. if no target path is provided
		# it returns the screenshot byte data.
		#
		# WARNING this method is synchronous so will cause a application to pause while the result is processed.
		#
		# This function returns the true if it is successful saved to a file, or if it is not saving to a file byte data is returned,
		# otherwise the method throws an exception.
		#
		def SaveTo(self, saveToFile = ''):
				id = self.Save()

				if (id == None or id == ""):
						return False

				#Wait for it to be possibly ready
				sleep((3000 + self.request.options.delay) / 1000)

				#Wait for it to be ready.
				while(1):
						status = self.GetStatus(id)
						if not(status.Cached) and not(status.Processing):
								raise GrabzItException.GrabzItException("The capture did not complete with the error: " + status.Message, GrabzItException.GrabzItException.RENDERING_ERROR)
								break
						elif status.Cached:
								result = self.GetResult(id)
								if result == None:
										raise GrabzItException.GrabzItException("The capture could not be found on GrabzIt.", GrabzItException.GrabzItException.RENDERING_MISSING_SCREENSHOT)
										break

								if (saveToFile == None or saveToFile == ""):
										return result
										
								fo = open(saveToFile, "wb")
								fo.write(result)				
								fo.close()
						
								break

						sleep(3)					
				return True
		
		#
		# This method returns the screenshot itself. If nothing is returned then something has gone wrong or the screenshot is not ready yet.
		#
		# id - The unique identifier of the screenshot, returned by the callback handler or the Save method
		#
		# This function returns the screenshot
		#
		def GetResult(self, id):
				if (id == "" or id == None):
						return None
				
				result = io.BytesIO(self.HTTPGet(self.WebServicesBaseURL + "getfile?id=" + id)).getvalue()
				
				if result == None or len(result) == 0:
						return None
				
				return result							
		
		#
		# Get the current status of a GrabzIt screenshot
		#
		# id - The id of the screenshot
		#
		# This function returns a Status object representing the screenshot
		#
		def GetStatus(self, id):
				
				if (id == "" or id == None):
						return None
				
				result = self.HTTPGet(self.WebServicesBaseURL + "getstatus?id=" + id)	 
				
				dom = minidom.parseString(result)
				
				processing = False
				cached = False
				expired = False
				message = ""
				
				messageNodes = dom.getElementsByTagName("Message")
				processingNodes = dom.getElementsByTagName("Processing")
				cachedNodes = dom.getElementsByTagName("Cached")
				expiredNodes = dom.getElementsByTagName("Expired")
				
				for messageNode in messageNodes:
						if messageNode.firstChild == None:
								break
						message = messageNode.firstChild.nodeValue
						break

				for processingNode in processingNodes:
						if processingNode.firstChild == None:
								break
						processing = (processingNode.firstChild.nodeValue == self.TrueString)
						break					
						
				for cachedNode in cachedNodes:
						if cachedNode.firstChild == None:
								break
						cached = (cachedNode.firstChild.nodeValue == self.TrueString)
						break					
						
				for expiredNode in expiredNodes:
						if expiredNode.firstChild == None:
								break
						expired = (expiredNode.firstChild.nodeValue == self.TrueString)
						break											

				return ScreenShotStatus.ScreenShotStatus(processing, cached, expired, message);			

		#
		# Get all the cookies that GrabzIt is using for a particular domain. This may include your user set cookies as well.
		#
		# domain - The domain to return cookies for.
		#
		# This function returns an array of cookies
		#
		def GetCookies(self, domain):
				sig =  self.CreateSignature(str(self.applicationSecret)+"|"+str(domain))
				qs = {"key":self.applicationKey, "domain":domain}
				encoded_qs = urlencode(qs)
				
				encoded_qs += "&sig="+sig

				dom = minidom.parseString(self.HTTPGet(self.WebServicesBaseURL + "getcookies?" + encoded_qs))

				self.CheckForException(dom)
						
				results = []

				cookieNodes = dom.getElementsByTagName("Cookie")
				
				for cookieNode in cookieNodes:
						name = cookieNode.getElementsByTagName('Name')
						domain = cookieNode.getElementsByTagName('Domain')
						value = cookieNode.getElementsByTagName('Value')
						path = cookieNode.getElementsByTagName('Path')
						expires = cookieNode.getElementsByTagName('Expires')
						httpOnly = cookieNode.getElementsByTagName('HttpOnly')
						type = cookieNode.getElementsByTagName('Type')
						
						results.append(GrabzItCookie.GrabzItCookie(self.GetFirstValue(name), self.GetFirstValue(value), self.GetFirstValue(domain), self.GetFirstValue(path), (self.GetFirstValue(httpOnly) == self.TrueString), self.GetFirstValue(expires), self.GetFirstValue(type)))																

				return results
				
		#
		# Sets a new custom cookie on GrabzIt, if the custom cookie has the same name and domain as a global cookie the global
		# cookie is overridden.
		#
		# This can be useful if a websites functionality is controlled by cookies.
		#
		# name - The name of the cookie to set.
		# domain - The domain of the website to set the cookie for.
		# value - The value of the cookie.
		# path - The website path the cookie relates to.
		# httponly - Is the cookie only used on HTTP
		# expires - When the cookie expires. Pass a empty string value if it does not expire.
		#
		# This function returns true if the cookie was successfully set.
		#
		def SetCookie(self, name, domain, value = "", path = "/", httponly = False, expires = ""):
				sig =  self.CreateSignature(str(self.applicationSecret)+"|"+str(name)+"|"+str(domain)+"|"+str(value)+"|"+str(path)+"|"+str(int(httponly))+"|"+str(expires)+"|0")		

				qs = {"key":self.applicationKey, "domain":domain, "name":name, "value":value, "path":path, "httponly":int(httponly), "expires":expires}

				encoded_qs = urlencode(qs)
				
				encoded_qs += "&sig="+sig;

				return self.IsSuccessful(self.HTTPGet(self.WebServicesBaseURL + "setcookie?" + encoded_qs))				  

		#
		# Delete a custom cookie or block a global cookie from being used.
		#
		# name - The name of the cookie to delete
		# domain - The website the cookie belongs to
		#
		# This function returns true if the cookie was successfully set.
		#				
		def DeleteCookie(self, name, domain):
				sig =  self.CreateSignature((str(self.applicationSecret)+"|"+str(name)+"|"+str(domain)+"|1"))

				qs = {"key":self.applicationKey, "domain":domain, "name":name, "delete":1}

				encoded_qs = urlencode(qs)
				
				encoded_qs += "&sig="+sig;

				return self.IsSuccessful(self.HTTPGet(self.WebServicesBaseURL + "setcookie?" + encoded_qs))				  

		#
		# Add a new custom watermark.
		#
		# identifier - The identifier you want to give the custom watermark. It is important that this identifier is unique.
		# path - The absolute path of the watermark on your server. For instance C:/watermark/1.png
		# xpos - The horizontal position you want the screenshot to appear at: Left = 0, Center = 1, Right = 2
		# ypos - The vertical position you want the screenshot to appear at: Top = 0, Middle = 1, Bottom = 2
		#
		# This function returns true if the watermark was successfully set.
		#
		def AddWaterMark(self, identifier, path, xpos, ypos):
				files = []
				try:					
						files.append(['watermark', os.path.basename(path), open(path, 'rb').read()])
				except:
						raise GrabzItException.GrabzItException("File: " + path + " does not exist", GrabzItException.GrabzItException.FILE_NON_EXISTANT_PATH)
				
				sig = self.CreateSignature(str(self.applicationSecret)+"|"+str(identifier)+"|"+str(xpos)+"|"+str(ypos))
				
				fields = {}
				fields['key'] = self.applicationKey
				fields['identifier'] = identifier
				fields['xpos'] = str(xpos)
				fields['ypos'] = str(ypos)
				fields['sig'] = sig
		
				return self.IsSuccessful(self.HTTPPost("/services/addwatermark", fields, files))
				
		#
		# Delete a custom watermark.
		#
		# identifier - The identifier of the custom watermark you want to delete
		#
		# This function returns true if the watermark was successfully deleted.
		#
		def DeleteWaterMark(self, identifier):
				sig = self.CreateSignature(str(self.applicationSecret)+"|"+str(identifier))

				qs = {"key":self.applicationKey, "identifier":identifier}

				encoded_qs = urlencode(qs)
				
				encoded_qs += "&sig="+sig

				return self.IsSuccessful(self.HTTPGet(self.WebServicesBaseURL + "deletewatermark?" + encoded_qs));		  

		#
		# Get your uploaded custom watermarks
		#
		# A GrabzItWaterMark array
		#
		def GetWaterMarks(self):
				return self.getWaterMarks()

		#
		# Get your uploaded custom watermark
		#
		# identifier - The identifier of a particular custom watermark you want to view
		#
		# the GrabzItWaterMark with the specified identifier
		#		
		def GetWaterMark(self, identifier):
				watermarks = self.getWaterMarks(identifier)
				if watermarks.Length == 1:
						return watermarks.get(0)
				return None		 
		
		#
		# This method sets if requests to GrabzIt's API should use SSL or not
		#
		# value - true if should use SSL
		#
		def UseSSL(self, value):
			if value:
				self.protocol = "https"
			else:
				self.protocol = "http"
				
		#
		# This method creates a cryptographically secure encryption key to pass to the encryption key parameter.
		#				 
		def CreateEncryptionKey(self):
			return base64.standard_b64encode(os.urandom(32)).decode('utf-8')
		
		#
		# This method will decrypt a encrypted capture file, using the key you passed to the encryption key parameter.
		#
		# data - the encrypted bytes
		# key - the encryption key		 
		#
		def Decrypt(self, data, key):
			if (data == None or data == ""):
				return None
				
			iv = data[0:16]
			payload = data[16:]
			cipher = AES.AESModeOfOperationCBC(base64.standard_b64decode(key), iv)
			decrypter = BlockFeeder.Decrypter(cipher, BlockFeeder.PADDING_NONE)
			decrypted = decrypter.feed(payload)
			decrypted += decrypter.feed()
			
			return decrypted	  
		
		#
		# This method will decrypt a encrypted capture, using the key you passed to the encryption key parameter.
		#
		# path - the path of the encrypted capture
		# key - the encryption key		  
		#
		def DecryptFile(self, path, key):
			data = self.ReadFile(path)
			fo = open(path, "wb")
			fo.write(self.Decrypt(data, key))				
			fo.close()			  
			
		def getWaterMarks(self, identifier = ""):
				sig = self.CreateSignature(str(self.applicationSecret)+"|"+str(identifier))

				qs = {"key":self.applicationKey, "identifier":identifier}

				encoded_qs = urlencode(qs)
				
				encoded_qs += "&sig="+sig;			   

				dom = minidom.parseString(self.HTTPGet(self.WebServicesBaseURL + "getwatermarks?" + encoded_qs))

				self.CheckForException(dom)
						
				results = []

				waterMarkNodes = dom.getElementsByTagName("WaterMark")
				
				for waterMarkNode in waterMarkNodes:
						identifier = waterMarkNode.getElementsByTagName('Identifier')
						xPosition = waterMarkNode.getElementsByTagName('XPosition')
						yPosition = waterMarkNode.getElementsByTagName('YPosition')
						format = waterMarkNode.getElementsByTagName('Format')
						
						results.append(GrabzItWaterMark.GrabzItWaterMark(self.GetFirstValue(identifier), self.GetFirstValue(xPosition), self.GetFirstValue(yPosition), self.GetFirstValue(format)))																

				return results
				
		def IsSuccessful(self, result):
				return self.GetResultObject(result, "Result") == self.TrueString
		
		def GetResultObject(self, result, resultTagName):
				dom = minidom.parseString(result)
				
				result = ""
								
				nodes = dom.getElementsByTagName(resultTagName)
				
				self.CheckForException(dom)
				
				for node in nodes:
						if node.firstChild == None:
								break
						result = node.firstChild.nodeValue
						break					
										
				return result
 
		def CheckForException(self, dom):
				if dom == None:
						return
				
				message = ""
				code = ""				
				
				messageNodes = dom.getElementsByTagName("Message")
				codeNodes = dom.getElementsByTagName("Code")
				
				for messageNode in messageNodes:
						if messageNode.firstChild == None:
								break
						message = messageNode.firstChild.nodeValue
						break

				for codeNode in codeNodes:
						if codeNode.firstChild == None:
								break
						code = codeNode.firstChild.nodeValue
						break
				
				if len(message) > 0:
						raise GrabzItException.GrabzItException(message, code)			
	   
				
		def GetFirstValue(self, node):
				if node.length > 0 and node[0].firstChild:
						return node[0].firstChild.nodeValue
				return ""
				
		def HTTPPost(self, selector, fields, files = None):
			content_type = ''
			body = ''
			
			if files != None:
					content_type, body = self.EncodeMultipartFormdata(fields, files)
			else:
					content_type = "application/x-www-form-urlencoded"
					body = urlencode(fields)					
					
 
			h = self._getConnection('POST', selector)
			h.putheader('content-type', content_type)
			h.putheader('content-length', str(len(body)))
			h.endheaders()
			
			try:
					h.send(body)
			except TypeError:
					# python 3 needs it to be encoded
					h.send(body.encode())
					
			response = h.getresponse()
			
			self.CheckResponseHeader(response.status);
			r = response.read()
			response.close()
			h.close()

			return r

		def _getConnection(self, method, action):
			hostname = self.WebServiceHostName
			port = 80
			username = None
			password = None
			authHeader = None
			
			if self.protocol == "https":
				port = 443
			
			if self.proxy:
				url = urlparse(self.proxy)
				hostname = url.hostname
				port = url.port					 
				username = unquote(url.username)
				password = unquote(url.password)
					
			h = None
			if self.protocol == "http":
				h = httpClient.HTTPConnection(hostname, port)
			else:
				h = httpClient.HTTPSConnection(hostname, port)
			
			if self.proxy:
				if username and password:
					auth = '%s:%s' % (username, password)
					
					try:
						authHeader = base64.b64encode(auth)
					except TypeError:
						authHeader = base64.b64encode(auth.encode()).decode("ISO-8859-1")
						
				h.putheader('proxy-authorization', 'Basic ' + authHeader)
				
				port = 80
				if self.protocol == "https":
					port = 443				  
				h.set_tunnel(self.WebServiceHostName, port)
			
			h.putrequest(method, action)

			return h
			
		def EncodeMultipartFormdata(self, fields, files):
			LIMIT = '----------lImIt_of_THE_fIle_eW_$'
			CRLF = '\r\n'
			L = []
			for (key, value) in fields.iteritems():
				L.append('--' + LIMIT)
				L.append('Content-Disposition: form-data; name="%s"' % key)
				L.append('')
				L.append(value)
			for (key, filename, value) in files:
				L.append('--' + LIMIT)
				L.append('Content-Disposition: form-data; name="%s"; filename="%s"' % (key, filename))
				L.append('Content-Type: %s' % self.GetContentType(filename))
				L.append('')
				L.append(value)
			L.append('--' + LIMIT + '--')
			L.append('')
			body = CRLF.join(L)
			content_type = 'multipart/form-data; boundary=%s' % LIMIT
			return content_type, body

		def GetContentType(self, filename):
			return mimetypes.guess_type(filename)[0] or 'application/octet-stream'
		
		def HTTPGet(self, url):
			connection = self._getConnection('GET', url)
			connection.endheaders()
			response = connection.getresponse()
			self.CheckResponseHeader(response.status)
			r = response.read()
			response.close()
			connection.close()

			return r		  
		
		def CheckResponseHeader(self, httpCode):
				if httpCode == 403:
						raise GrabzItException.GrabzItException('Rate limit reached. Please wait for your service to resume shortly. Also please slow the rate of requests you are sending to GrabzIt to ensure this does not happen in the future.', GrabzItException.GrabzItException.NETWORK_DDOS_ATTACK)
				elif httpCode >= 400:
						raise GrabzItException.GrabzItException('A network error occurred when connecting to GrabzIt.', GrabzItException.GrabzItException.NETWORK_GENERAL_ERROR)

		def CreateSignature(self, value):
				md5 = hashlib.md5()
				md5.update(value.encode('ascii', 'replace'))
				return md5.hexdigest()
				
		def ReadFile(self, path):
				try:					
						return open(path, 'rb').read()
				except:
						raise GrabzItException.GrabzItException("File: " + path + " does not exist", GrabzItException.GrabzItException.FILE_NON_EXISTANT_PATH)
		



#!/usr/bin/python

from GrabzIt import GrabzItBaseOptions

class GrabzItAnimationOptions(GrabzItBaseOptions.GrabzItBaseOptions):
        """ Available options when creating a animated GIF

            Attributes:

            width               set the width of the resulting animated GIF in pixels
            height              set the height of the resulting animated GIF in pixels
            start               set the starting position of the video that should be converted into an animated GIF
            duration            set the length in seconds of the video that should be converted into a animated GIF
            speed               set the speed of the animated GIF from 0.2 to 10 times the original speed
            framesPerSecond     set the number of frames per second that should be captured from the video. From a minimum of 0.2 to a maximum of 60
            repeat              set the number of times to loop the animated GIF. If 0 it will loop forever
            reverse             set to true if the frames of the animated GIF should be reversed
            customWaterMarkId   set a custom watermark to add to the animated GIF
            quality             set the quality of the image where 0 is poor and 100 excellent. The default is -1 which uses the recommended quality
        """

        def __init__(self):
                GrabzItBaseOptions.GrabzItBaseOptions.__init__(self)
                self.width = 0
                self.height = 0
                self.start = 0
                self.duration = 1
                self.speed = 0
                self.framesPerSecond = 0
                self.repeat = 0
                self.reverse = False
                self.customWaterMarkId = ''
                self.quality = -1

        def _getParameters(self, applicationKey, sig, callBackURL, dataName, dataValue):
                params = self._createParameters(applicationKey, sig, callBackURL, dataName, dataValue)
                params["width"] = int(self.width)
                params["height"] = int(self.height)
                params["duration"] = int(self.duration) 
                params["start"] = int(self.start) 
                params["speed"] = self._toString(self.speed) 
                params["fps"] = self._toString(self.framesPerSecond)
                params["repeat"] = int(self.repeat) 
                params["reverse"] = int(self.reverse)
                params["customwatermarkid"] = str(self.customWaterMarkId) 
                params["quality"] = int(self.quality) 

                return params

        def _getSignatureString(self, applicationSecret, callBackURL, url = ''):
                urlParam = '';
                if (url != None and url != ''):
                        urlParam = str(url)+"|"

                callBackURLParam = '';
                if (callBackURL != None and callBackURL != ''):
                        callBackURLParam = str(callBackURL)

                return applicationSecret +"|"+ urlParam + callBackURLParam + \
                "|"+str(int(self.height))+"|"+str(int(self.width))+"|"+str(self.customId)+"|"+self._toString(self.framesPerSecond)+"|"+self._toString(self.speed)+"|"+str(int(self.duration))+ \
                "|"+str(int(self.repeat))+"|"+str(int(self.reverse))+"|"+str(int(self.start))+"|"+str(self.customWaterMarkId)+"|"+str(self.country)+"|"+str(int(self.quality))+"|"+str(self.exportURL)+"|"+str(self.encryptionKey)+"|"+str(self.proxy)

        def _toString(self, value):
                if ((value % 1) == 0):
                        return str(int(value))
                return str(float(value))


#!/usr/bin/python

from GrabzIt import GrabzItBaseOptions

class GrabzItHTMLOptions(GrabzItBaseOptions.GrabzItBaseOptions):
        """ Available options when creating rendered HTML

            Attributes:

            browserWidth        the width of the browser in pixels
            browserHeight       the height of the browser in pixels. Use -1 to screenshot the whole web page
            delay               the number of milliseconds to wait before creating the capture
            waitForElement      the CSS selector of the HTML element in the web page that must be visible before the capture is performed
            requestAs           the user agent type should be used: Standard Browser = 0, Mobile Browser = 1, Search Engine = 2 and Fallback Browser = 3
            noAds               set to true if adverts should be automatically hidden
            address                 the URL to execute the HTML code in
            noCookieNotifications   set to true if cookie notifications should be automatically hidden
            clickElement            the CSS selector of the HTML element in the web page to click
            jsCode                  the JavaScript code to execute in the web page            
        """

        def __init__(self):
                GrabzItBaseOptions.GrabzItBaseOptions.__init__(self)
                self.browserWidth = 0
                self.browserHeight = 0
                self.waitForElement = ''
                self.requestAs = 0
                self.noAds = False
                self.noCookieNotifications = False
                self.address = ''
                self.clickElement = ''
                self.jsCode = ''                
        
        #
        # Define a HTTP Post parameter and optionally value, this method can be called multiple times to add multiple parameters. Using this method will force 
        # GrabzIt to perform a HTTP post.
        #
        # name - The name of the HTTP Post parameter
        # value - The value of the HTTP Post parameter
        #               
        def AddPostParameter(self, name, value):
                self.post = self._appendParameter(self.post, name, value)
        
        def _getParameters(self, applicationKey, sig, callBackURL, dataName, dataValue):
                params = self._createParameters(applicationKey, sig, callBackURL, dataName, dataValue)
                params["bwidth"] = int(self.browserWidth)
                params["bheight"] = int(self.browserHeight)
                params["delay"] = int(self.delay)
                params["waitfor"] = str(self.waitForElement)                
                params["requestmobileversion"] = int(self.requestAs)
                params['noads'] = int(self.noAds)
                params["post"] = str(self.post)
                params["address"] = str(self.address)
                params["nonotify"] = int(self.noCookieNotifications)
                params["click"] = str(self.clickElement)
                params["jscode"] = str(self.jsCode)

                return params

        def _getSignatureString(self, applicationSecret, callBackURL, url = ''):
                urlParam = ''
                if (url != None and url != ''):
                        urlParam = str(url)+"|"

                callBackURLParam = ''
                if (callBackURL != None and callBackURL != ''):
                        callBackURLParam = str(callBackURL)

                return applicationSecret +"|"+ urlParam + callBackURLParam + \
                "|"+str(int(self.browserHeight))+"|"+str(int(self.browserWidth))+"|"+str(self.customId)+ \
                "|"+str(int(self.delay))+"|"+str(int(self.requestAs))+"|"+str(self.country)+"|"+str(self.exportURL)+ \
                "|"+str(self.waitForElement)+"|"+str(self.encryptionKey)+"|"+str(int(self.noAds))+"|"+str(self.post)+ \
                "|"+str(self.proxy)+"|"+str(self.address)+"|"+str(int(self.noCookieNotifications))+ \
                "|"+str(self.clickElement)+"|"+str(self.jsCode)
                


#!/usr/bin/python

import unittest
from GrabzIt import GrabzItClient
from GrabzIt import GrabzItImageOptions

class TestGrabzItClient(unittest.TestCase):
    def setUp(self):
        self.client = GrabzItClient.GrabzItClient("c3VwcG9ydEBncmFiei5pdA==", "Q9PBV2f_F74t3eoBeNXSIizK1Dk2UizMXRWWWZqlZa4")

    def test_html_to_image(self):
        self.client.HTMLToImage("<h1>Hello world</h1>")
        self.assertNotEqual(self.client.Save(), "", "HTML not converted")

    def test_html_to_video(self):
        self.client.HTMLToVideo("<h1>Hello world</h1>")
        self.assertNotEqual(self.client.Save(), "", "HTML not converted")       

    def test_url_to_video(self):
        self.client.URLToVideo("https://grabz.it")
        self.assertNotEqual(self.client.Save(), "", "URL not converted")         

    def test_url_to_html(self):
        self.client.URLToRenderedHTML("https://grabz.it")
        self.assertNotEqual(self.client.Save(), "", "URL not converted")         

if __name__ == '__main__':
    unittest.main()


#!/usr/bin/python

from GrabzIt import GrabzItBaseOptions

class GrabzItPDFOptions(GrabzItBaseOptions.GrabzItBaseOptions):
        """ Available options when creating a PDF capture

            Attributes:

            includeBackground       set to true if the background of the web page should be included in the PDF
            pagesize                the page size of the PDF to be returned: 'A3', 'A4', 'A5', 'A6', 'B3', 'B4', 'B5', 'B6', 'Letter'
            orientation             the orientation of the PDF to be returned: 'Landscape' or 'Portrait'
            includeLinks            set to true if links should be included in the PDF
            includeOutline          set to true if the PDF outline should be included
            title                   the title for the PDF document
            coverURL                the URL of a web page that should be used as a cover page for the PDF
            marginTop               the margin that should appear at the top of the PDF document page
            marginLeft              the margin that should appear at the left of the PDF document page
            marginBottom            the margin that should appear at the bottom of the PDF document page
            marginRight             the margin that should appear at the right of the PDF document
            browserWidth            the width of the browser in pixels
            delay                   the number of milliseconds to wait before creating the capture
            targetElement           the CSS selector of the only HTML element in the web page to capture
            hideElement             the CSS selector(s) of the one or more HTML elements in the web page to hide
            waitForElement          the CSS selector of the HTML element in the web page that must be visible before the capture is performed
            requestAs               which user agent type should be used: Standard Browser = 0, Mobile Browser = 1, Search Engine = 2 and Fallback Browser = 3
            templateId              a template ID that specifies the header and footer of the PDF document
            customWaterMarkId       a custom watermark to add to the PDF
            quality                 the quality of the PDF where 0 is poor and 100 excellent. The default is -1 which uses the recommended quality
            noAds                   set to true if adverts should be automatically hidden
            pageHeight              set the height of the resulting PDF in mm
            pageWidth               set the width of the resulting PDF in mm
            mergeId                 the ID of a capture that should be merged at the beginning of the new PDF document
            address                 the URL to execute the HTML code in
            noCookieNotifications   set to true if cookie notifications should be automatically hidden
            cssMediaType            the css media type to use either 'Print' or 'Screen'
            password                the password to protect the PDF document with
            clickElement            the CSS selector of the HTML element in the web page to click
            jsCode                  the JavaScript code to execute in the web page
        """
        
        def __init__(self):
                GrabzItBaseOptions.GrabzItBaseOptions.__init__(self)
                self.includeBackground = True
                self.pagesize = 'A4'
                self.orientation = 'Portrait'
                self.includeLinks = True
                self.includeOutline = False
                self.title = ''
                self.coverURL = ''
                self.marginTop = 10
                self.marginLeft = 10
                self.marginBottom = 10
                self.marginRight = 10
                self.browserWidth = 0
                self.requestAs = 0
                self.templateId = ''
                self.customWaterMarkId = ''
                self.quality = -1
                self.targetElement = ''
                self.hideElement = ''
                self.waitForElement = ''
                self.noAds = False
                self.templateVariables = ''
                self.pageHeight = 0
                self.pageWidth = 0
                self.mergeId = ''
                self.noCookieNotifications = False
                self.address = ''
                self.cssMediaType = ''
                self.password = ''
                self.clickElement = ''
                self.jsCode = ''
                
        #
        # Define a HTTP Post parameter and optionally value, this method can be called multiple times to add multiple parameters. Using this method will force 
        # GrabzIt to perform a HTTP post.
        #
        # name - The name of the HTTP Post parameter
        # value - The value of the HTTP Post parameter
        #               
        def AddPostParameter(self, name, value):
                self.post = self._appendParameter(self.post, name, value)
                
        #
        # Define a custom template parameter and value, this method can be called multiple times to add multiple parameters.
        #
        # name - The name of the template parameter
        # value - The value of the template parameter
        #               
        def AddTemplateParameter(self, name, value):
                self.templateVariables = self._appendParameter(self.templateVariables, name, value)
                
        def _getParameters(self, applicationKey, sig, callBackURL, dataName, dataValue):
                params = self._createParameters(applicationKey, sig, callBackURL, dataName, dataValue)
                params["background"] = int(self.includeBackground)
                params["pagesize"] = str(self.pagesize.upper())
                params["orientation"] = str(self.orientation.title())
                params["includelinks"] = int(self.includeLinks)
                params["includeoutline"] = int(self.includeOutline)
                params["title"] = str(self.title)
                params["coverurl"] = str(self.coverURL) 
                params["mtop"] = int(self.marginTop)
                params["mleft"] = int(self.marginLeft)
                params["mbottom"] = int(self.marginBottom)
                params["mright"] = int(self.marginRight)
                params["delay"] = int(self.delay)
                params["templateid"] = str(self.templateId)
                params["requestmobileversion"] = int(self.requestAs)
                params["customwatermarkid"] = str(self.customWaterMarkId) 
                params["quality"] = int(self.quality)
                params["target"] = str(self.targetElement)
                params["hide"] = str(self.hideElement)
                params["waitfor"] = str(self.waitForElement)
                params["noads"] = int(self.noAds)
                params["post"] = str(self.post)
                params["bwidth"] = int(self.browserWidth)
                params["tvars"] = str(self.templateVariables)
                params["width"] = int(self.pageWidth)
                params["height"] = int(self.pageHeight)
                params["mergeid"] = str(self.mergeId)
                params["address"] = str(self.address)
                params["nonotify"] = int(self.noCookieNotifications)
                params["media"] = str(self.cssMediaType)
                params["password"] = str(self.password)
                params["click"] = str(self.clickElement)
                params["jscode"] = str(self.jsCode)
                
                return params
                
        def _getSignatureString(self, applicationSecret, callBackURL, url = ''):
                urlParam = ''
                if (url != None and url != ''):
                        urlParam = str(url)+"|"

                callBackURLParam = ''
                if (callBackURL != None and callBackURL != ''):
                        callBackURLParam = str(callBackURL)

                return applicationSecret +"|"+ urlParam + callBackURLParam + \
                "|"+str(self.customId)+"|"+str(int(self.includeBackground))+"|"+str(self.pagesize.upper()) +"|"+str(self.orientation.title())+"|"+str(self.customWaterMarkId)+ \
                "|"+str(int(self.includeLinks))+"|"+str(int(self.includeOutline))+"|"+str(self.title)+"|"+str(self.coverURL)+"|"+str(int(self.marginTop))+ \
                "|"+str(int(self.marginLeft))+"|"+str(int(self.marginBottom))+"|"+str(int(self.marginRight))+"|"+str(int(self.delay))+"|"+str(int(self.requestAs))+ \
                "|"+str(self.country)+"|"+str(int(self.quality))+"|"+str(self.templateId)+"|"+str(self.hideElement)+"|"+str(self.targetElement)+"|"+str(self.exportURL)+\
                "|"+str(self.waitForElement)+"|"+str(self.encryptionKey)+"|"+str(int(self.noAds))+"|"+str(self.post)+"|"+str(int(self.browserWidth))+"|"+str(int(self.pageHeight))+\
                "|"+str(int(self.pageWidth))+"|"+str(self.templateVariables)+"|"+str(self.proxy)+"|"+str(self.mergeId)+"|"+str(self.address)+"|"+str(int(self.noCookieNotifications))+ \
                "|"+str(self.cssMediaType)+"|"+str(self.password)+"|"+str(self.clickElement)+"|"+str(self.jsCode)


#!/usr/bin/python

from GrabzIt import GrabzItBaseOptions

class GrabzItVideoOptions(GrabzItBaseOptions.GrabzItBaseOptions):
        """ Available options when creating a video

            Attributes:

            browserWidth        the width of the browser in pixels
            browserHeight       the height of the browser in pixels
            width               the width of the resulting video in pixels
            height              the height of the resulting video in pixels
            start               set starting time of the web page that should be converted into a video
            duration            set length in seconds of the web page that should be converted into a video
            framesPerSecond     set number of frames per second that should be used to create the video. From a minimum of 0.2 to a maximum of 10
            customWaterMarkId   set a custom watermark to add to the video
            clickElement        the CSS selector of the HTML element in the web page to click
            waitForElement      the CSS selector of the HTML element in the web page that must be visible before the capture is performed
            requestAs           the user agent type should be used: Standard Browser = 0, Mobile Browser = 1, Search Engine = 2 and Fallback Browser = 3
            noAds               set to true if adverts should be automatically hidden
            noCookieNotifications   set to true if cookie notifications should be automatically hidden
            address                 the URL to execute the HTML code in
            jsCode                  the JavaScript code to execute in the web page
        """

        def __init__(self):
                GrabzItBaseOptions.GrabzItBaseOptions.__init__(self)
                self.browserWidth = 0
                self.browserHeight = 0
                self.width = 0
                self.height = 0                
                self.start = 0
                self.duration = 10
                self.framesPerSecond = 0
                self.customWaterMarkId = ''
                self.clickElement = ''
                self.waitForElement = ''
                self.requestAs = 0
                self.noAds = False
                self.noCookieNotifications = False
                self.address = ''
                self.jsCode = ''

        def _getParameters(self, applicationKey, sig, callBackURL, dataName, dataValue):
                params = self._createParameters(applicationKey, sig, callBackURL, dataName, dataValue)
                params["bwidth"] = int(self.browserWidth)
                params["bheight"] = int(self.browserHeight)
                params["width"] = int(self.width)
                params["height"] = int(self.height)                
                params["duration"] = int(self.duration) 
                params["start"] = int(self.start) 
                params["fps"] = self._toString(self.framesPerSecond)
                params["waitfor"] = str(self.waitForElement)     
                params["requestmobileversion"] = int(self.requestAs)
                params["customwatermarkid"] = str(self.customWaterMarkId) 
                params['noads'] = int(self.noAds)
                params["post"] = str(self.post)
                params["address"] = str(self.address)
                params["nonotify"] = int(self.noCookieNotifications)
                params["click"] = str(self.clickElement)
                params["jscode"] = str(self.jsCode)

                return params

        def _getSignatureString(self, applicationSecret, callBackURL, url = ''):
                urlParam = ''
                if (url != None and url != ''):
                        urlParam = str(url)+"|"

                callBackURLParam = ''
                if (callBackURL != None and callBackURL != ''):
                        callBackURLParam = str(callBackURL)

                return applicationSecret +"|"+ urlParam + callBackURLParam + \
                "|"+str(int(self.browserHeight))+"|"+str(int(self.browserWidth))+"|"+str(self.customId)+"|"+str(self.customWaterMarkId)+"|"+str(int(self.start))+"|"+str(int(self.requestAs)) + \
                "|"+str(self.country)+"|"+str(self.exportURL)+"|"+str(self.waitForElement)+"|"+str(self.encryptionKey)+"|"+str(int(self.noAds))+"|"+str(self.post)+"|"+str(self.proxy) + \
                "|"+str(self.address)+"|"+str(int(self.noCookieNotifications))+"|"+str(self.clickElement)+"|"+self._toString(self.framesPerSecond)+"|"+str(int(self.duration)) + \
                "|"+str(int(self.width))+"|"+str(int(self.height))+"|"+str(self.jsCode)

        def _toString(self, value):
                if ((value % 1) == 0):
                        return str(int(value))
                return str(float(value))


#!/usr/bin/python

class GrabzItCookie:

	def __init__(self, name, value, domain, path, httponly, expires, type):
		self.Name = name
		self.Value = value
		self.Domain = domain
		self.Path = path
		self.HttpOnly = httponly
		self.Expires = expires
		self.Type = type


#!/usr/bin/python

try:
	from urllib.parse import urlencode
except ImportError:
	from urllib import urlencode

class GrabzItBaseOptions():
        """ Common options when creating a capture on GrabzIt

            Attributes:

            customId        A custom identifier that you can pass through to the web service. This will be returned with the callback URL you have specified
            country         The country the capture should be created from: Default = "", Singapore = "SG", UK = "UK", US = "US"
            exportURL       The export URL that should be used to transfer the capture to a third party location
            encryptionKey   The encryption key that will be used to encrypt your capture
        """
        def __init__(self):
                self.customId = ""
                self.country = ""
                self.exportURL = ""
                self.encryptionKey = ""
                self.delay = 0
                self.post = ""
                self.proxy = ""

        def _appendParameter(self, qs, name, value):
            val = ""
            if (name != None and name != ""):
                if (value == None):
                    value = ""
                val = urlencode({name:value})
        
            if (val == ""):
                return qs
                
            if (qs != ""):
                qs += "&"
                
            qs += val
            return qs
                
        def _createParameters(self, applicationKey, sig, callBackURL, dataName, dataValue):
            return {"key":str(applicationKey), "country": str(self.country), "export": str(self.exportURL), "encryption": str(self.encryptionKey), "proxy": str(self.proxy), "customid": str(self.customId), "callback": str(callBackURL), "sig": str(sig), str(dataName):str(dataValue)}


#!/usr/bin/env python

from distutils.core import setup
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.txt')) as f:
    long_description = f.read()

setup(name='GrabzIt',
      version='3.5.7',
      author='GrabzIt',
      author_email='support@grabz.it',
      url='https://grabz.it/api/python/',
      license='MIT Licence',
      description='GrabzIt enables allows you to programmatically convert web pages and HTML into images, DOCX, videos, rendered HTML, PDFs, CSVs and spreadsheets. Additionally GrabzIt allows you to convert online videos into animated GIFs',
      long_description=long_description,
      long_description_content_type='text/markdown',
      packages=['GrabzIt']      
)



#!/usr/bin/python

class ScreenShotStatus:

    def __init__(self, processing, cached, expired, message):
        self.Processing = processing
        self.Cached = cached
        self.Expired = expired
        self.Message = message



from GrabzIt import GrabzItCookie
from GrabzIt import ScreenShotStatus
from GrabzIt import GrabzItWaterMark
from GrabzIt import GrabzItException
from GrabzIt import GrabzItBaseOptions
from GrabzIt import GrabzItAnimationOptions
from GrabzIt import GrabzItImageOptions
from GrabzIt import GrabzItPDFOptions
from GrabzIt import GrabzItDOCXOptions
from GrabzIt import GrabzItTableOptions
from GrabzIt import GrabzItHTMLOptions
from GrabzIt import GrabzItVideoOptions
from GrabzIt import GrabzItClient